/*
   Allocate storage for the arrays,
   initialize the data part of the arrays to zero,
   and then initialize the boundary conditions in the arrays.
*/

void InitializeData(double*** new_p, double*** val_p, int n)
{
   int i, j;

   /* allocate storage */
   /* see http://c-faq.com/aryptr/dynmuldimary.html */
   double** val = (double**)malloc( (n+2) * sizeof(double*) );
   double** new = (double**)malloc( (n+2) * sizeof(double*) );
   val[0] = (double*)malloc( (n+2) * (n+2) * sizeof(double) );
   new[0] = (double*)malloc( (n+2) * (n+2) * sizeof(double) );
   for(i = 1; i < n+2; i++)
   {
      val[i] = val[0] + (i * (n+2));
      new[i] = new[0] + (i * (n+2));
   }
   /* initialize to 0.0 */
   for(i = 0; i < n+2; i++)
   {
      for(j = 0; j < n+2; j++)
      {
         val[i][j] = 0.0;
         new[i][j] = 0.0;
      }
   }
   /* now put in boundary conditions */
   for(i = 0; i < (n/11); i++)
   {
      // left edge
      val[i]         [0] = 1.0;
      val[(5*n/11)+i][0] = 1.0;
      val[n+1-i]     [0] = 1.0;
      // right edge
      val[i]         [n+1] = 1.0;
      val[(5*n/11)+i][n+1] = 1.0;
      val[n+1-i]     [n+1] = 1.0;
      // top edge
      val[0][i]          = 1.0;
      val[0][(5*n/11)+i] = 1.0;
      val[0][n+1-i]      = 1.0;
      // bottom edge
      val[n+1][i]          = 1.0;
      val[n+1][(5*n/11)+i] = 1.0;
      val[n+1][n+1-i]      = 1.0;

      // left edge
      new[i]         [0] = 1.0;
      new[(5*n/11)+i][0] = 1.0;
      new[n+1-i]     [0] = 1.0;
      // right edge
      new[i]         [n+1] = 1.0;
      new[(5*n/11)+i][n+1] = 1.0;
      new[n+1-i]     [n+1] = 1.0;
      // top edge
      new[0][i]          = 1.0;
      new[0][(5*n/11)+i] = 1.0;
      new[0][n+1-i]      = 1.0;
      // bottom edge
      new[n+1][i]          = 1.0;
      new[n+1][(5*n/11)+i] = 1.0;
      new[n+1][n+1-i]      = 1.0;
   }

   *new_p = new;
   *val_p = val;
}/* InitializeData() */